<?php
//
//############################################################################################
//#  php_speedchex_serverlinkadvanced.php
//############################################################################################
//#
//# This script is a functioning example that shows PHP programmers how to utilize 
//# the SpeedChex ServerLink Advanced API to submit checking account and customer 
//# data to SpeedChex for authorization.  The script also shows sample code for parsing
//# the results sent back from SpeedChex.  Please contact your support representative
//# if you do not have a copy of the SpeedChex ServerLink Advanced API documentation.
//#
//# In order to establish an HTTPS connection, pass data to the SpeedChex Gateway and receive
//# a response, you will need to have cURL installed (http://curl.haxx.se).  
//#
//# This script expects to receive the following data fields as POST or QUERY STRING (GET)
//# variables:
//#     
//#     InvoiceNumber
//#     CheckAmount
//#     CustomerID
//#     FirstName
//#     LastName
//#     Company
//#     Address
//#     City
//#     State
//#     Zip
//#     Phone
//#     Email
//#     BankName
//#     AccountType
//#     AccountClass
//#     RoutingNumber
//#     CheckNumber
//#     AccountNumber
//#
//# The data format specifications and rules about which fields are required and which fields
//# are optional can be found in the SpeedChex ServerLink Advanced API documentation.
//# 
//# Programmers may use all or any part of this code and can make whatever modifications are
//# necessary to integrate this code into their PHP application.
//#
//# When you are ready to test this code, you will need to change the MerchantID,
//# LoginName, and Password fields to those provided by your SpeedChex support representative.
//#
//###############################################################################################



//#############################################
//#  Build HTTPS GET string
//#############################################
$url = 'https://www.speedchex.com/datalinks/merchants/serverlink-advanced.asp' . 
                             '?MerchantID=2001' .
                             '&GateID=test' .
                             '&GateKey=test' .
                             '&TestMode=on' .
                             '&ReferenceID=' . urlencode($_POST['InvoiceNumber']) .
                             '&PaymentDirection=FromCustomer' .
                             '&CheckAmount=' . urlencode($_POST['Amount']) .
                             '&DateScheduled=' . urlencode(date('mDY')) . 
                             '&CustomerID=' . urlencode($_POST['CustomerID']) .
                             '&CustomerName=' . urlencode($_POST['FirstName'] . " " . $_POST['LastName']) .
                             '&Company=' . urlencode($_POST['Company']) .
                             '&Address1=' . urlencode($_POST['Address']) .
                             '&City=' . urlencode($_POST['City']) .
                             '&State=' . urlencode($_POST['State']) .
                             '&Zip=' . urlencode($_POST['Zip']) .
                             '&Phone=' . urlencode($_POST['Phone']) .
                             '&Email=' . urlencode($_POST['Email']) .
                             '&SendEmailToCustomer=Yes' .
                             '&BankName=' . urlencode($_POST['BankName']) .
                             '&AccountType=' . urlencode($_POST['AccountType']) .
                             '&AccountClass=' . urlencode($_POST['AccountClass']) .
                             '&RoutingNumber=' . urlencode($_POST['RoutingNumber']) .
                             '&CheckNumber=' . urlencode($_POST['CheckNumber']) .
                             '&AccountNumber=' . urlencode($_POST['AccountNumber']);

echo "<b>HTTP GET string sent to SpeedChex:</b><BR>";
echo $url ;


//############################################
//# Establish cURL connection
//############################################
$ch = curl_init();

curl_setopt($ch, CURLOPT_URL, $url);


// Set curl options to retrieve response from SpeedChex
curl_setopt($ch, CURLOPT_RETURNTRANSFER,1);

// Execute curl to post the check data to the SpeedChex
$result=curl_exec ($ch);

// Close the curl object
curl_close ($ch);

//Show result text from check authorization attempt
echo "<BR><BR><BR><b>Response from SpeedChex Gateway:</b><BR>";
echo $result;


//#######################################################
//#  Parse the response from SpeedChex Gateway
//#    Note: These output messages are just examples.   
//#          Modify this code to control how you want
//#          to interact with your customer if there
//#          is a problem.
//#######################################################

echo "<BR><BR><BR><b>Parsed Response:</b><BR>";

   //Parse results into variables.  NVPair is short for Name Value Pair
   list($ReturnCodeNVPair, $ErrorDescriptionNVPair, $ErrorFieldNVPair, $TrackingCode) = split(',', $result);

   if ($ReturnCodeNVPair == 'ReturnCode=000') {
     //Put code here to conclude the customer's transaction
     echo 'Authorization Successful';
   }
   else {
     //Parse the NameValue pairs into variables
     list($ReturnCodeName, $ReturnCodeValue) = split('=',$ReturnCodeNVPair);
     list($ErrorDescriptionName, $ErrorDescriptionValue) = split('=',$ErrorDescriptionNVPair);
     list($ErrorFieldName, $ErrorFieldValue) = split('=',$ErrorFieldNVPair);

     switch ($ReturnCodeValue) {
       case '001':  //Invalid Login

                    echo "You are not using valid login information.  &nbsp;This is not a customer issue.";
      	 break;

       case '002':  //Required Field Missing

                    echo "A field required by SpeedChex (" . $ErrorFieldValue . ") has not been sent. &nbsp;This is not a customer issue.";
         break;

       case '003':  //Field Value Violates Format Constraint
                    //  We request that you have your program do error checking instead of using SpeedChex to do error
                    //  checking for you.  If you get this error, you will want to fix your error checking process.
                    //  The $ErrorFieldValue variable will show you what field has invalid data.

                    echo 'Invalid data contained in the ' . $ErrorFieldValue . ' field.';
         break;

       case '004':  //Field Value Exceeds Maximum Length
                    //  We request that you have your program do error checking instead of using SpeedChex to do error
                    //  checking for you.  If you get this error, you will want to fix your error checking process.
                    //  The $ErrorFieldValue variable will show you what field has invalid data.

                    echo 'Data exceeds maximum length in the ' . $ErrorFieldValue . ' field.';
         break;

       case '005':  //Routing Number Fails Authentication
                    //  The customer has entered an invalid routing number.
					
                    echo 'You have entered an invalid routing number.';
         break;

       case '006':  //Transaction Request Already Processed
                    //  SpeedChex has already processed this check and will not process it again
					
                    echo 'This check has already been accepted and does not need to be submitted again.';
         break;

       case '007':  //Please Contact Support Representative
         
                    echo "Return Code 007 is an internal security response and is not a customer related issue.";
 					
         break;

       case '008':  //Failed Verification
                    //  The $ErrorDescriptionValue variable will contain the SpeedChex Express Verify Response Code and 
					//  Response Text separated by a colon.  See document SpeedChex_ExpressVerify_Response_Codes.doc 
                    //  for a list of all possible negative response codes.
					
                    //Get the Express Verify Response Text			
                    list($ExpressVerifyResponseCode, $ExpressVerifyResponseText) = split(':',$ErrorDescriptionValue);
	            echo 'Account Failed Verification: &nbsp;We apologize, but we cannot accept a check on this bank account. &nbsp;The account has
                          failed verification due to its current status.<BR><BR>Your business is very important to us. &nbsp;Please review the routing number and the
                          account number for any input errors. &nbsp;If you are sure the account information is correct, you
                          may want to contact your banking institution to discuss the current status of your account and how
                          it may have affected this transaction.';
         break;

       default:     //All other response codes

                    echo 'This response code (' . $ResponseCodeValue . ') indicates an unknown error and requires assistance
                          from the SpeedChex technical support staff.';
     } // switch
   } // if else

?>
